@@ -1,6 +1,6 @@
 import numpy as np
 from sklearn.linear_model import LinearRegression
-from c1algo2 import data
+from c1algo2 import data, evaluator
 import logging
 
 
@@ -100,41 +100,60 @@ def forecast(historical_data, previous_enrollment, schedule, verbose=False):
     else:
         logging.basicConfig(level=logging.INFO)
 
-    sequencer_inputs = data.parse_input(historical_data, previous_enrollment)
-    sizer_inputs = data.model_1_output(sequencer_inputs)
+    (
+        sequencer_combined_inputs,
+        sequencer_training_inputs,
+        sequencer_testing_inputs
+    ) = data.parse_input(historical_data, previous_enrollment)
+    sizer_training_inputs = data.model_1_output(sequencer_training_inputs)
+    sizer_testing_inputs = data.model_1_output(sequencer_testing_inputs)
 
-    courses = data.get_courses(schedule)
+    courses = data.get_dynamic_courses(schedule)
 
     sizer = LinearRegression()
     sequencer = LinearRegression()
 
-    x_years, y_enrollments = create_model_1_input(sizer_inputs)
-    x_year_enrollment, y_semesters = create_model_2_input(sequencer_inputs)
+    x_years_training, y_enrollments_training = create_model_1_input(sizer_training_inputs)
+    x_year_enrollment_training, y_semesters_training = create_model_2_input(sequencer_training_inputs)
 
-    outputDict = {}
+    x_years_testing, y_enrollments_testing = create_model_1_input(sizer_testing_inputs)
+    x_year_enrollment_testing, y_semesters_testing = create_model_2_input(sequencer_testing_inputs)
+
+    size_output_dict = {}
+    size_testing_dict = {}
+
+    sequence_output_dict = {}
+    sequence_testing_dict = {}
 
     for course in courses:
-        sizer.fit(x_years[course], y_enrollments[course])
-        sequencer.fit(x_year_enrollment[course], y_semesters[course])
-        # !IS - Are these performance metrics?
-        # r_sq_1 = sizer.score(x_years[course], y_enrollments[course])
-        # r_sq_2 = sequencer.score(x_year_enrollment[course], y_semesters[course])
-        y1_pred_floats = sizer.predict(x_year_enrollment[course][:, 0].reshape(-1, 1))
-        y1_pred = round_floats_to_ints(y1_pred_floats)
-        x_2 = np.array([x_year_enrollment[course][:, 0], y1_pred]).transpose()
+        sizer.fit(x_years_training[course], y_enrollments_training[course])
+        sequencer.fit(x_year_enrollment_training[course], y_semesters_training[course])
+        y1_pred_floats = sizer.predict(x_year_enrollment_testing[course][:, 0].reshape(-1, 1))
+        y1_pred = np.array(round_floats_to_ints(y1_pred_floats), dtype=np.int32)
+        # This is currently only doing predictions for 1 year
+        x_2 = [np.array([x_year_enrollment_training[course][:, 0][0], y1_pred[0]]).transpose()]
         y2_pred_floats = sequencer.predict(x_2)
         y2_pred = round_floats_to_ints(y2_pred_floats)
 
-        outputDict[course] = y2_pred[0]
+        size_output_dict[course] = y1_pred[0]
+        size_testing_dict[course] = y_enrollments_testing[course][0]
+        sequence_testing_dict[course] = y_semesters_testing[course][0]
+        sequence_output_dict[course] = y2_pred[0]
 
         logging.debug("    **** " + str(course) + " Predicted Sequencing ****")
-        for input, pred in zip(x_year_enrollment[course], y2_pred):
+        for input, pred in zip(x_year_enrollment_training[course], y2_pred):
             logging.debug("Year: " + str(int(input[0])) + "     Size: " + str(int(input[1])) + "    Prediction:" + str(pred))
 
-    normalize_output(outputDict)
+    sizer_rating = evaluator.sizer_score(size_output_dict, size_testing_dict)
+    sequencer_rating = evaluator.sequencer_score(sequence_output_dict, sequence_testing_dict)
 
-    schedule = data.fill_capacities(schedule, outputDict, 2022)
+    logging.debug(sizer_rating)
+    logging.debug(sequencer_rating)
 
-    logging.info(outputDict)
+    normalize_output(sequence_output_dict)
+
+    schedule = data.fill_capacities(schedule, sequence_output_dict)
+
+    logging.info(sequence_output_dict)
 
     return schedule
